# generated-repo-3

## Quick start

```bash
pip install generated-repo-3
```

```python
from generated_package import ...
```

## Contributing

```bash
# clone the repo
git clone https://github.com/phitoduck/generated-repo-3.git

# install the dev dependencies
make install

# run the tests
make test
```
